@@ -31,7 +31,7 @@ def MapperMethod(requestClass=None, responseClass=None) :
                 args = FlaskManager.getArgsWithResponseClassInstanceAppended(args, responseClass)
                 methodReturn = resourceInstanceMethod(*args,**kwargs)
             except Exception as exception :
-                FlaskManager.raiseGlobalException(exception, resourceInstance, resourceInstanceMethod)
+                FlaskManager.raiseAndPersistGlobalException(exception, resourceInstance, resourceInstanceMethod)
             return methodReturn
         ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
         return innerResourceInstanceMethod
